module AnchorUi
  module Webpacker
    class CoreUi < AnchorUi::Core::Assets::Base
      include AnchorUi::Core::Assets::Concerns::CoreUi

      def update
        ensure_module
        compile_coreui_scss
        compile_variables_scss
        puts 'CoreUi updated'
      end

      private

      def root_path
        @tmp_path || begin
          Pathname.new File.expand_path("#{__dir__}/../../..")
        end
      end

      def templates_path
        root_path.join 'lib/generators/anchor_ui/webpacker/templates'
      end

      def node_path
        tmp_path.join 'node_modules/@coreui/coreui'
      end

      def stylesheets_source_path
        node_path.join stylesheets_relative_path
      end

      def ensure_module
        unless Dir.exists?(node_path)
          FileUtils.mkdir_p tmp_path
          system "cd #{tmp_path} && yarn install && yarn add chalk @coreui/coreui@#{version}"
        end
      end

      def compile_coreui_scss
        super(
          '~@coreui/coreui/scss',
          '~@coreui/icons/scss/coreui-icons'
        )
      end

      def compile_variables_scss
        super(
          <<~SCSS,
            @import
              '~bootstrap/scss/functions',
              '~bootstrap/scss/variables';

          SCSS
          <<~SCSS

            // Paths
            $simple-line-font-path: '~simple-line-icons/fonts/';
            $fa-font-path: '~font-awesome/fonts';
            $flag-icon-css-path: '~flag-icon-css/flags';
            $coreui-icons-font-path: '~@coreui/icons/fonts';
          SCSS
        )
      end

    end
  end
end
